<?php
require_once('LoginForm.php');
require_once('MonAdaptateurAuth.php');
/**
 *  Le cas d’utilisation typique serait :

 * l’utilisateur clique sur le lien du formulaire d’authentification
 * l’utilisateur soumet le formulaire
 * le contrôleur traite le formulaire
 o une erreur de validation provoque l’affichage du formulaire avec le ou les messages d’erreurs
 o une identification correcte redirige vers la page d’accueil
 * l’utilisateur connecté est redirigé vers la page d’accueil
 * l’action logout déconnecte l’utilisateur et le redirige vers le formulaire de logi
 *
 *
 */
class LoginController extends Zend_Controller_Action
{
	public function getForm()
	{
		$baseurl = Zend_Controller_Front::getInstance()->getBaseUrl();
		return new LoginForm(array(
            'action' => $baseurl . '/login/process',
            'method' => 'post'
            ));
	}

	public function getAuthAdapter($params)
	{
		return new MonAdaptateurAuth($params['username'], $params['password']);
	}

	public function preDispatch()
	{
		if (Zend_Auth::getInstance()->hasIdentity()) {
			// If the user is logged in, we don't want to show the login form;
			// however, the logout action should still be available
			if ('logout' != $this->getRequest()->getActionName()) {
 			    //              redirector(méthode d'action, controleur)
				$this->_helper->redirector('index', 'index');
			}
		} else {
			// If they aren't, they can't logout, so that action should
			// redirect to the login form
			if ('logout' == $this->getRequest()->getActionName()) {
				//              redirector(méthode d'action, controleur) 
				$this->_helper->redirector('index', 'login');
			}
		}
	}

	
	public function indexAction()
	{
		// on transmet le formulaire contruit dynamiquement 
		$this->view->form = $this->getForm();
	}


	public function processAction()
	{
		$request = $this->getRequest();

		// Check if we have a POST request
		if (!$request->isPost()) {
			return $this->_helper->redirector('index');
		}

		// Get our form and validate it
		$form = $this->getForm();
		if (!$form->isValid($request->getPost())) {
			// Invalid entries
			$this->view->form = $form;
			return $this->render('index'); // re-render the login form
		}

		// Définition de l'adaptateur d'authentification
		// MonAdaptateurAuth est une classe que vous avez définie, 
		// qui implémente Zend_Auth_Adapter_Interface
		// avec un constructeur acceptant 2 arguments
		//Zend_Debug::dump($form->getValues());
		$adapter = $this->getAuthAdapter($form->getValues());

		// Obtention d'une référence de l'instance du Singleton de Zend_Auth
		$auth = Zend_Auth::getInstance();
			
		// Tentative d'authentification et stockage du résultat 
		$result  = $auth->authenticate($adapter);

		if (!$result->isValid()) {
			// Invalid credentials
			$form->setDescription('Données reçues invalides');
			$this->view->form = $form;
			return $this->render('index'); // re-render the login form
		}

		// We're authenticated! Redirect to the home page
		$this->_helper->redirector('index', 'index');
	}

	public function logoutAction()
	{
		Zend_Auth::getInstance()->clearIdentity();
		$this->_helper->redirector('index'); // back to login page
	}

}